from src.replacers.ner_replacer import NERReplacer
from src.detections import NameDetection, SurnameDetection, DateDetection, CityDetection
from src.dictionaries.morphosyntactic.ner_file import NERFileMorphosyntacticDictionary
from tempfile import NamedTemporaryFile


def test_ner_replacer():
    with NamedTemporaryFile() as file:
        file.writelines(
            [
                "name	Andrzej	Andrzej	a\n".encode("utf-8"),
                "name	Kasi	Kasia	b\n".encode("utf-8"),
                "surname	Kowalowi	Kowal	a\n".encode("utf-8"),
                "surname	Kowal	Kowal	b\n".encode("utf-8"),
            ]
        )
        file.flush()

        dictionary = NERFileMorphosyntacticDictionary(file.name, always_replace=False)

        text = "Ala Brzeszczot urodziła sie 05.05.2005 we Wrocławiu"
        detections = [
            (0, 3, NameDetection(morpho_tag="a")),
            (4, 14, SurnameDetection(morpho_tag="b")),
            (28, 38, DateDetection()),
            (42, 51, CityDetection(morpho_tag="c")),
        ]

        replacer = NERReplacer(dictionary)

        result = replacer.replace(text, detections)

        expected_text = "Andrzej Kowal urodziła sie 05.05.2005 we Wrocławiu"
        exptected_detections_left = [
            (27, 37, DateDetection()),
            (41, 50, CityDetection(morpho_tag="c")),
        ]

        assert result == (expected_text, exptected_detections_left)
